# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

<!-- <END NEW CHANGELOG ENTRY> -->

## [v0.1.1] - 2024-01-15
### :sparkles: New Features
- [`3f851af`](https://github.com/SUSTech-data/neopyter/commit/3f851af093d95e673148895e7b96d8b90207ea58) - add kernel/execute_command, add husky as githook tools *(commit by [@AbaoFromCUG](https://github.com/AbaoFromCUG))*

### :wrench: Chores
- [`6da87d9`](https://github.com/SUSTech-data/neopyter/commit/6da87d978af0cc86de13b0749d856fbf47bf042e) - add commitlint config *(commit by [@AbaoFromCUG](https://github.com/AbaoFromCUG))*
- [`56d4750`](https://github.com/SUSTech-data/neopyter/commit/56d4750760f46617a7e4cebc172e84a531f477ea) - update pre-commit config *(commit by [@AbaoFromCUG](https://github.com/AbaoFromCUG))*


[v0.1.1]: https://github.com/SUSTech-data/neopyter/compare/v0.1.0...v0.1.1